quantizationtools.NullAttackPointOptimizer
==========================================

.. abjad-lineage:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer

.. autoclass:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__call__
      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__eq__
      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__format__
      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__ne__
      ~abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__repr__

Bases
-----

- :py:class:`quantizationtools.AttackPointOptimizer <abjad.tools.quantizationtools.AttackPointOptimizer.AttackPointOptimizer>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.NullAttackPointOptimizer.NullAttackPointOptimizer.__repr__
   :noindex:
